@@ -2,7 +2,7 @@
 #
 #   optdepends.sh - Check the 'optdepends' array conforms to requirements.
 #
-#   Copyright (c) 2014-2018 Pacman Development Team <pacman-dev@archlinux.org>
+#   Copyright (c) 2014-2019 Pacman Development Team <pacman-dev@archlinux.org>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@ LIBMAKEPKG_LINT_PKGBUILD_OPTDEPENDS_SH=1
 
 LIBRARY=${LIBRARY:-'/usr/share/makepkg'}
 
+source "$LIBRARY/lint_pkgbuild/fullpkgver.sh"
+source "$LIBRARY/lint_pkgbuild/pkgname.sh"
 source "$LIBRARY/util/message.sh"
 source "$LIBRARY/util/pkgbuild.sh"
 
@@ -31,15 +33,21 @@ lint_pkgbuild_functions+=('lint_optdepends')
 
 
 lint_optdepends() {
-	local a list name optdepends_list ret=0
-
-	local optdepends_list optdepend name ret=0
+	local optdepends_list optdepend name ver ret=0
 
 	get_pkgbuild_all_split_attributes optdepends optdepends_list
 
-	for optdepend in "${optdepends_list[@]}"; do
-		name=${optdepend%%:[[:space:]]*}
+	# this function requires extglob - save current status to restore later
+	local shellopts=$(shopt -p extglob)
+	shopt -s extglob
+
+	for optdepend in "${optdepends_list[@]%%:[[:space:]]*}"; do
+		name=${optdepend%%@(<|>|=|>=|<=)*}
 		lint_one_pkgname optdepends "$name" || ret=1
+		if [[ $name != "$optdepend" ]]; then
+			ver=${optdepend##$name@(<|>|=|>=|<=)}
+			check_fullpkgver "$ver" optdepends || ret=1
+		fi
 	done
 
 	return $ret
